@@ -371,6 +371,8 @@
 #define OPENBSDID 12
 #define WIN32ID 13
 #define HPUX11ID 14
+#define AIXID 15
+#define MACOSXID 16
 #define UNKNOWNID 255
 
 #ifdef hpux9
@@ -394,7 +396,7 @@
 #ifdef ultrix4
 #define OSTYPE ULTRIXID
 #endif
-#ifdef netbsd1
+#if defined(netbsd1) || defined(netbsd2)
 #define OSTYPE NETBSD1ID
 #endif
 #if defined(__FreeBSD__)
@@ -409,12 +411,18 @@
 #if defined(bsdi2) || defined(bsdi3) || defined(bsdi4)
 #define OSTYPE BSDIID
 #endif
-#ifdef openbsd2
+#if defined(openbsd2) || defined(openbsd3)
 #define OSTYPE OPENBSDID
 #endif
 #ifdef WIN32
 #define OSTYPE WIN32ID
 #endif
+#if defined(aix3) || defined(aix4) || defined(aix5)
+#define OSTYPE AIXID
+#endif
+#ifdef darwin8
+#define OSTYPE MACOSXID
+#endif
 /* unknown */
 #ifndef OSTYPE
 #define OSTYPE UNKNOWNID
@@ -530,10 +538,15 @@
 
 #ifndef HAVE_INDEX
 #ifdef HAVE_STRCHR
+#ifdef mingw32
+# define index(a,b) strchr(a,b)
+# define rindex(a,b) strrchr(a,b)
+#else
 # define index strchr
 # define rindex strrchr
 #endif
 #endif
+#endif
 
 #ifndef HAVE_MEMCPY
 #ifdef HAVE_BCOPY
@@ -742,6 +755,9 @@
 /* define if agentx transport is to use domain sockets only */
 #undef AGENTX_DOM_SOCK_ONLY
 
+/* define if you do not want snmptrapd to register as an AgentX subagent */
+#undef SNMPTRAPD_DISABLE_AGENTX
+
 #undef HEIMDAL
 
 #endif /* NET_SNMP_CONFIG_H */
