@@ -235,12 +235,15 @@ create_trap_session(char *sink, u_short sinkport,
 {
     netsnmp_session session, *sesp;
     char           *peername = NULL;
+    int             len;
 
-    if ((peername = malloc(strlen(sink) + 4 + 32)) == NULL) {
+    len = strlen(sink) + 4 + 32;
+    if ((peername = malloc(len)) == NULL) {
         return 0;
+    } else if (NULL != strchr(sink,':')) {
+        snprintf(peername, len, "%s", sink);
     } else {
-        snprintf(peername, strlen(sink) + 4 + 32, "udp:%s:%hu", sink,
-                 sinkport);
+        snprintf(peername, len, "udp:%s:%hu", sink, sinkport);
     }
 
     memset(&session, 0, sizeof(netsnmp_session));
@@ -250,6 +253,15 @@ create_trap_session(char *sink, u_short sinkport,
         session.community = (u_char *) com;
         session.community_len = strlen(com);
     }
+
+    /*
+     * for informs, set retries to default
+     */
+    if (SNMP_MSG_INFORM == pdutype) {
+        session.timeout = SNMP_DEFAULT_TIMEOUT;
+        session.retries = SNMP_DEFAULT_RETRIES;
+    }
+
     /*
      * if the sink is localhost, bind to localhost, to reduce open ports.
      */
@@ -615,7 +627,7 @@ netsnmp_send_traps(int trap, int specific,
 
     DEBUGMSGTL(( "trap", "send_trap %d %d ", trap, specific));
     DEBUGMSGOID(("trap", enterprise, enterprise_length));
-    DEBUGMSGTL(( "trap", "\n"));
+    DEBUGMSG(( "trap", "\n"));
 
     if (vars) {
         vblist = snmp_clone_varbind( vars );
@@ -749,6 +761,17 @@ netsnmp_send_traps(int trap, int specific,
             return -1;
         }
     }
+
+    /*
+     * Check whether we're ignoring authFail traps
+     */
+    if (template_v1pdu->trap_type == SNMP_TRAP_AUTHFAIL &&
+        snmp_enableauthentraps == SNMP_AUTHENTICATED_TRAPS_DISABLED) {
+        snmp_free_pdu(template_v1pdu);
+        snmp_free_pdu(template_v2pdu);
+        return 0;
+    }
+
     /*
      * Ensure that the v1 trap PDU includes the local IP address
      */
@@ -795,6 +818,45 @@ send_enterprise_trap_vars(int trap,
     return;
 }
 
+/**
+ * Captures responses or the lack there of from INFORMs that were sent
+ * 1) a response is received from an INFORM
+ * 2) one isn't received and the retries/timeouts have failed
+*/
+int
+handle_inform_response(int op, netsnmp_session * session,
+                       int reqid, netsnmp_pdu *pdu,
+                       void *magic)
+{
+    /* XXX: possibly stats update */
+    switch (op) {
+
+    case NETSNMP_CALLBACK_OP_RECEIVED_MESSAGE:
+        snmp_increment_statistic(STAT_SNMPINPKTS);
+        DEBUGMSGTL(("trap", "received the inform response for reqid=%d\n",
+                    reqid));
+        break;
+
+    case NETSNMP_CALLBACK_OP_TIMED_OUT:
+        DEBUGMSGTL(("trap",
+                    "received a timeout sending an inform for reqid=%d\n",
+                    reqid));
+        break;
+
+    case NETSNMP_CALLBACK_OP_SEND_FAILED:
+        DEBUGMSGTL(("trap",
+                    "failed to send an inform for reqid=%d\n",
+                    reqid));
+        break;
+
+    default:
+        DEBUGMSGTL(("trap", "received op=%d for reqid=%d when trying to send an inform\n", op, reqid));
+    }
+
+    return 1;
+}
+
+
 /*
  * send_trap_to_sess: sends a trap to a session but assumes that the
  * pdu is constructed correctly for the session type. 
@@ -803,7 +865,6 @@ void
 send_trap_to_sess(netsnmp_session * sess, netsnmp_pdu *template_pdu)
 {
     netsnmp_pdu    *pdu;
-    netsnmp_pdu    *response;
     int            result;
 
     if (!sess || !template_pdu)
@@ -826,10 +887,13 @@ send_trap_to_sess(netsnmp_session * sess, netsnmp_pdu *template_pdu)
          || template_pdu->command == AGENTX_MSG_NOTIFY
 #endif
        ) {
-        result = snmp_synch_response(sess, pdu, &response);
-        result = !result;	/* XXX - different return code :-( */
-    } else
+        result =
+            snmp_async_send(sess, pdu, &handle_inform_response, NULL);
+        
+    } else {
         result = snmp_send(sess, pdu);
+    }
+
     if (result == 0) {
         snmp_sess_perror("snmpd: send_trap", sess);
         /* snmp_free_pdu(pdu); */
