@@ -171,9 +171,10 @@ netsnmp_scalar_group_helper_handler(netsnmp_mib_handler *handler,
          * If we didn't get an answer (due to holes in the group)
 	 *   set things up to retry again.
          */
-        if (requests->requestvb->type == ASN_NULL ||
-            requests->requestvb->type == SNMP_NOSUCHOBJECT ||
-            requests->requestvb->type == SNMP_NOSUCHINSTANCE) {
+        if (!requests->delegated &&
+            (requests->requestvb->type == ASN_NULL ||
+             requests->requestvb->type == SNMP_NOSUCHOBJECT ||
+             requests->requestvb->type == SNMP_NOSUCHINSTANCE)) {
             snmp_set_var_objid(requests->requestvb,
                                reginfo->rootoid, reginfo->rootoid_len);
             requests->requestvb->name[reginfo->rootoid_len-1] = ++subid;
