@@ -1076,7 +1076,7 @@ var_hrswrun(struct variable * vp,
 #else
         long_return = proc_buf->p_swrss;
 #endif
-#elif HAVE_KVM_GETPROCS
+#elif HAVE_KVM_GETPROCS && !defined(darwin8)
 #if defined(freebsd3) && !defined(darwin)
         long_return =
     #if defined(freebsd5)
@@ -1283,7 +1283,7 @@ Init_HR_SWRun(void)
     pstat_getproc(proc_table, sizeof(struct pst_status), nproc, 0);
 
 #elif defined(solaris2)
-    if (!getKstatInt("unix", "system_misc", "nproc", &nproc)) {
+    if (getKstatInt("unix", "system_misc", "nproc", &nproc)) {
         current_proc_entry = nproc + 1;
         return;
     }
