@@ -326,7 +326,8 @@ vacm_parse_view(const char *token, char *param)
     struct vacm_viewEntry *vp;
     oid             suboid[MAX_OID_LEN];
     size_t          suboid_len = 0;
-    u_char          viewMask[sizeof(vp->viewMask)];
+    size_t          mask_len = 0;
+    u_char          viewMask[VACMSTRINGLEN];
     int             i;
     char            *st;
 
@@ -378,6 +379,7 @@ vacm_parse_view(const char *token, char *param)
             viewMask[i] = val;
             i++;
         }
+        mask_len = i;
     } else {
         for (i = 0; i < sizeof(viewMask); i++)
             viewMask[i] = 0xff;
@@ -388,6 +390,7 @@ vacm_parse_view(const char *token, char *param)
         return;
     }
     memcpy(vp->viewMask, viewMask, sizeof(viewMask));
+    vp->viewMaskLen = mask_len;
     vp->viewType = inclexcl;
     vp->viewStorageType = SNMP_STORAGE_PERMANENT;
     vp->viewStatus = SNMP_ROW_ACTIVE;
