@@ -83,7 +83,7 @@ u_char          smux_str[SMUXMAXSTRLEN];
 int             smux_listen_sd = -1;
 
 static struct timeval smux_rcv_timeout;
-static u_long   smux_reqid;
+static long   smux_reqid;
 
 void            init_smux(void);
 static u_char  *smux_open_process(int, u_char *, size_t *, int *);
@@ -98,7 +98,7 @@ static void     smux_list_detach(smux_reg **, smux_reg **);
 static void     smux_replace_active(smux_reg *, smux_reg *);
 static void     smux_peer_cleanup(int);
 static int      smux_auth_peer(oid *, size_t, char *, int);
-static int      smux_build(u_char, u_long, oid *,
+static int      smux_build(u_char, long, oid *,
                            size_t *, u_char, u_char *, size_t, u_char *,
                            size_t *);
 static int      smux_list_add(smux_reg **, smux_reg *);
@@ -143,6 +143,10 @@ smux_parse_peer_auth(const char *token, char *cptr)
         snmp_log_perror("smux_parse_peer_auth: malloc");
         return;
     }
+    if (nauths == SMUX_MAX_PEERS) {
+	config_perror("Too many smuxpeers");
+	return;
+    }
     aptr->sa_active_fd = -1;
     if (!cptr) {
         /*
@@ -153,24 +157,16 @@ smux_parse_peer_auth(const char *token, char *cptr)
         return;
     }
 
-    if (*cptr == '.')
-        cptr++;
-
-    if (!isdigit(*cptr)) {
-        config_perror("second token is not an OID");
-        free((char *) aptr);
-        return;
-    }
     /*
      * oid 
      */
-    aptr->sa_oid_len = parse_miboid(cptr, aptr->sa_oid);
+    aptr->sa_oid_len = MAX_OID_LEN;
+    read_objid( cptr, aptr->sa_oid, &aptr->sa_oid_len );
 
     DEBUGMSGTL(("smux_conf", "parsing registration for: %s\n", cptr));
 
-    while (isdigit(*cptr) || *cptr == '.')
-        cptr++;
-    cptr = skip_white(cptr);
+    cptr = skip_token(cptr);
+    DEBUGMSGTL(("smux_conf", "password is: %s\n", cptr ? cptr : "NULL"));
 
     /*
      * password 
@@ -1545,7 +1541,7 @@ smux_parse_var(u_char * varbind,
  */
 static int
 smux_build(u_char type,
-           u_long reqid,
+           long reqid,
            oid * objid,
            size_t * oidlen,
            u_char val_type,
@@ -1566,7 +1562,7 @@ smux_build(u_char type,
     /*
      * build reqid 
      */
-    ptr = asn_build_unsigned_int(ptr, &len,
+    ptr = asn_build_int(ptr, &len,
                                  (u_char) (ASN_UNIVERSAL | ASN_PRIMITIVE |
                                            ASN_INTEGER), &reqid,
                                  sizeof(reqid));
