@@ -853,7 +853,7 @@ int   command_handler( netsnmp_pdu           *pdu,
         /*
          *  and pass this formatted string to the command specified
          */
-        run_exec_command(handler->token, rbuf, NULL, 0);   /* Not interested in output */
+        run_shell_command(handler->token, rbuf, NULL, 0);   /* Not interested in output */
         snmp_set_quick_print(oldquick);
         if (pdu->command == SNMP_MSG_TRAP)
             snmp_free_pdu(v2_pdu);
@@ -948,6 +948,14 @@ snmp_input(int op, netsnmp_session *session,
 
     switch (op) {
     case NETSNMP_CALLBACK_OP_RECEIVED_MESSAGE:
+        /*
+         * Drops packets with reception problems
+         */
+        if (session->s_snmp_errno) {
+            /* drop problem packets */
+            return 1;
+        }
+
         /*
 	 * Determine the OID that identifies the trap being handled
 	 */
