@@ -202,6 +202,8 @@ struct snmp_session {
     char           *peername;
     /** UDP port number of peer. */
     u_short         remote_port;
+    /** My Domain name or dotted IP address, 0 for default */
+    char           *localname;
     /** My UDP port number, 0 for default, picked randomly */
     u_short         local_port;     
     /**
@@ -258,6 +260,7 @@ struct snmp_session {
     char           *securityName;
     /** Length of securityName. */
     size_t          securityNameLen;
+
     /** auth protocol oid */
     oid            *securityAuthProto;
     /** Length of auth protocol oid */
@@ -266,6 +269,11 @@ struct snmp_session {
     u_char          securityAuthKey[USM_AUTH_KU_LEN];       
     /** Length of Ku for auth protocol */
     size_t          securityAuthKeyLen;
+    /** Kul for auth protocol */
+    u_char          *securityAuthLocalKey;       
+    /** Length of Kul for auth protocol XXX */
+    size_t          securityAuthLocalKeyLen;       
+
     /** priv protocol oid */
     oid            *securityPrivProto;
     /** Length of priv protocol oid */
@@ -274,6 +282,11 @@ struct snmp_session {
     u_char          securityPrivKey[USM_PRIV_KU_LEN];       
     /** Length of Ku for priv protocol */
     size_t          securityPrivKeyLen;
+    /** Kul for priv protocol */
+    u_char          *securityPrivLocalKey;       
+    /** Length of Kul for priv protocol XXX */
+    size_t          securityPrivLocalKeyLen;       
+
     /** snmp security model, v1, v2c, usm */
     int             securityModel;
     /** noAuthNoPriv, authNoPriv, authPriv */
@@ -328,9 +341,17 @@ typedef struct request_list {
 #define SNMP_DEFAULT_VERSION	    -1
 #define SNMP_DEFAULT_SECMODEL	    -1
 #define SNMP_DEFAULT_CONTEXT        ""
+#ifndef DISABLE_MD5
 #define SNMP_DEFAULT_AUTH_PROTO     usmHMACMD5AuthProtocol
+#else
+#define SNMP_DEFAULT_AUTH_PROTO     usmHMACSHA1AuthProtocol
+#endif
 #define SNMP_DEFAULT_AUTH_PROTOLEN  USM_LENGTH_OID_TRANSFORM
+#ifndef DISABLE_DES
 #define SNMP_DEFAULT_PRIV_PROTO     usmDESPrivProtocol
+#else
+#define SNMP_DEFAULT_PRIV_PROTO     usmAESPrivProtocol
+#endif
 #define SNMP_DEFAULT_PRIV_PROTOLEN  USM_LENGTH_OID_TRANSFORM
 
     extern const char *snmp_api_errstring(int);
@@ -463,8 +484,9 @@ typedef struct request_list {
 #define SNMPERR_VAR_TYPE		(-61)
 #define SNMPERR_MALLOC			(-62)
 #define SNMPERR_KRB5			(-63)
+#define SNMPERR_PROTOCOL		(-64)
 
-#define SNMPERR_MAX			(-63)
+#define SNMPERR_MAX			(-64)
 
 #define non_repeaters	errstat
 #define max_repetitions errindex
@@ -956,6 +978,7 @@ struct variable_list {
                                            netsnmp_session * ss);
     void            snmp_sess_perror(const char *prog_string,
                                      netsnmp_session * ss);
+    const char *    snmp_pdu_type(int type);
 
     /*
      * end single session API 
