@@ -8,6 +8,7 @@ $0 [-v VERSION] -R -C -M -D -h
 
   -M           Modify the files with a new version (-v required)
   -v VERSION   Use VERSION as the version string
+  -T TAG       Use TAG as CVS tag (must being with Ext-)
   -C           Commit changes to the files
   -R           Reverse files (rm and cvs update)
   -D           Compare files (cvs diff)
@@ -56,6 +57,12 @@ my @exprs = (
 	       repl => 'VERSION = \'$VERSION\'',
 	       files => [qw(dist/Makefile)]},
 
+	     # Doxygen config
+	     { type => 'doxygen',
+	       expr => 'PROJECT_NUMBER(\s+)=(\s+)\'(.*)\'',
+	       repl => 'PROJECT_NUMBER$1=$2\'$VERSION\'',
+	       files => [qw(doxygen.conf)]},
+
 	     # perl files
 	     { type => 'perl',
 	       expr => 'VERSION = \'(.*)\'',
@@ -68,6 +75,7 @@ my @exprs = (
 			    perl/ASN/ASN.pm
 			    perl/AnyData_SNMP/Storage.pm
 			    perl/AnyData_SNMP/Format.pm
+			    perl/TrapReceiver/TrapReceiver.pm
 			   )]}
 	    );
 
