@@ -1,6 +1,6 @@
 /*
  * container_null.c
- * $Id: container_null.c,v 1.4 2004/03/01 01:01:59 rstory Exp $
+ * $Id: container_null.c,v 1.4.2.1 2005/07/20 22:14:56 rstory Exp $
  *
  * see comments in header file.
  *
@@ -29,7 +29,7 @@
 #include <net-snmp/types.h>
 #include <net-snmp/library/snmp_api.h>
 #include <net-snmp/library/container.h>
-#include <net-snmp/library/container_binary_array.h>
+#include <net-snmp/library/container_null.h>
 #include <net-snmp/library/tools.h>
 #include <net-snmp/library/snmp_assert.h>
 
