@@ -432,17 +432,23 @@ read_config_get_handlers(const char *type)
 }
 
 void
-read_config_with_type(const char *filename, const char *type)
+read_config_with_type_when(const char *filename, const char *type, int when)
 {
     struct config_line *ctmp = read_config_get_handlers(type);
     if (ctmp)
-        read_config(filename, ctmp, EITHER_CONFIG);
+        read_config(filename, ctmp, when);
     else
         DEBUGMSGTL(("read_config",
                     "read_config: I have no registrations for type:%s,file:%s\n",
                     type, filename));
 }
 
+void
+read_config_with_type(const char *filename, const char *type)
+{
+    read_config_with_type_when(filename, type, EITHER_CONFIG);
+}
+
 
 struct config_line *
 read_config_find_handler(struct config_line *line_handlers,
@@ -795,14 +801,43 @@ free_config(void)
                 (*(ltmp->free_func)) ();
 }
 
+void
+read_configs_optional(const char *optional_config, int when)
+{
+    char *newp, *cp, *st;
+    char *type = netsnmp_ds_get_string(NETSNMP_DS_LIBRARY_ID, 
+				       NETSNMP_DS_LIB_APPTYPE);
+
+    if ((NULL == optional_config) || (NULL == type))
+        return;
+
+    DEBUGMSGTL(("read_configs_optional",
+                "reading optional configuration tokens for %s\n", type));
+    
+    newp = strdup(optional_config);      /* strtok_r messes it up */
+    cp = strtok_r(newp, ",", &st);
+    while (cp) {
+        struct stat     statbuf;
+        if (stat(cp, &statbuf)) {
+            DEBUGMSGTL(("read_config",
+                        "Optional File \"%s\" does not exist.\n", cp));
+            snmp_log_perror(cp);
+        } else {
+            DEBUGMSGTL(("read_config",
+                        "Reading optional config file: \"%s\"\n", cp));
+            read_config_with_type_when(cp, type, when);
+        }
+        cp = strtok_r(NULL, ",", &st);
+    }
+    free(newp);
+    
+}
+
 void
 read_configs(void)
 {
     char *optional_config = netsnmp_ds_get_string(NETSNMP_DS_LIBRARY_ID, 
 					       NETSNMP_DS_LIB_OPTIONALCONFIG);
-    char *type = netsnmp_ds_get_string(NETSNMP_DS_LIBRARY_ID, 
-				       NETSNMP_DS_LIB_APPTYPE);
-    char *st;
 
     DEBUGMSGTL(("read_config", "reading normal configuration tokens\n"));
 
@@ -814,27 +849,8 @@ read_configs(void)
     /*
      * do this even when the normal above wasn't done 
      */
-    if (optional_config && type) {
-      char           *newp, *cp;
-      newp = strdup(optional_config);      /* strtok_r messes it up */
-      cp = strtok_r(newp, ",", &st);
-      while (cp) {
-        struct stat     statbuf;
-        if (stat(cp, &statbuf)) {
-            DEBUGMSGTL(("read_config",
-                        "Optional File \"%s\" does not exist.\n",
-                        cp));
-            snmp_log_perror(cp);
-        } else {
-            DEBUGMSGTL(("read_config",
-                        "Reading optional config file: \"%s\"\n",
-                        cp));
-            read_config_with_type(cp, type);
-        }
-        cp = strtok_r(NULL, ",", &st);
-      }
-      free(newp);
-    }
+    if (NULL != optional_config)
+        read_configs_optional(optional_config, NORMAL_CONFIG);
 
     netsnmp_config_process_memories_when(NORMAL_CONFIG, 1);
 
@@ -847,6 +863,9 @@ read_configs(void)
 void
 read_premib_configs(void)
 {
+    char *optional_config = netsnmp_ds_get_string(NETSNMP_DS_LIBRARY_ID, 
+					       NETSNMP_DS_LIB_OPTIONALCONFIG);
+
     DEBUGMSGTL(("read_config", "reading premib configuration tokens\n"));
 
     if (!netsnmp_ds_get_boolean(NETSNMP_DS_LIBRARY_ID, 
@@ -854,6 +873,9 @@ read_premib_configs(void)
         read_config_files(PREMIB_CONFIG);
     }
 
+    if (NULL != optional_config)
+        read_configs_optional(optional_config, PREMIB_CONFIG);
+
     netsnmp_config_process_memories_when(PREMIB_CONFIG, 0);
 
     netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, 
@@ -1065,7 +1087,7 @@ read_config_files(int when)
 	    envconfpath = strdup(envconfpath);
         }
 
-        DEBUGMSGTL(("read_config", "config path used:%s\n", envconfpath));
+        DEBUGMSGTL(("read_config", "config path used: %s\n", envconfpath));
         cptr1 = cptr2 = envconfpath;
         i = 1;
         while (i && *cptr2 != 0) {
@@ -1353,18 +1375,18 @@ snmp_clean_persistent(const char *type)
  * line number of a .conf file and increments the error count. 
  */
 void
-config_perror(const char *string)
+config_perror(const char *str)
 {
     snmp_log(LOG_ERR, "%s: line %d: Error: %s\n", curfilename, linecount,
-             string);
+             str);
     config_errors++;
 }
 
 void
-config_pwarn(const char *string)
+config_pwarn(const char *str)
 {
     snmp_log(LOG_WARNING, "%s: line %d: Warning: %s\n", curfilename,
-             linecount, string);
+             linecount, str);
 }
 
 /*
