@@ -283,7 +283,7 @@ snmp_log_options(char *optarg, int argc, char *const *argv)
      * Finally, handle ".... -Lx value ...." syntax
      *   (*without* surrounding quotes)
      */
-    if (!*optarg) {
+    if ((!*optarg) && (NULL != argv)) {
         /*
          * We've run off the end of the argument
          *  so move on to the next.
@@ -410,7 +410,7 @@ snmp_log_options(char *optarg, int argc, char *const *argv)
 }
 
 char *
-snmp_log_syslogname(char *pstr)
+snmp_log_syslogname(const char *pstr)
 {
   if (pstr)
     strncpy (syslogname, pstr, sizeof(syslogname));
@@ -548,6 +548,25 @@ snmp_disable_filelog(void)
             snmp_disable_filelog_entry(logh);
 }
 
+/*
+ * returns that status of stderr logging
+ *
+ * @retval 0 : stderr logging disabled
+ * @retval 1 : stderr logging enabled
+ */
+snmp_stderrlog_status(void)
+{
+    netsnmp_log_handler *logh;
+
+    for (logh = logh_head; logh; logh = logh->next)
+        if (logh->enabled && (logh->type == NETSNMP_LOGHANDLER_STDOUT ||
+                              logh->type == NETSNMP_LOGHANDLER_STDERR)) {
+            return 1;
+       }
+
+    return 0;
+}
+
 void
 snmp_disable_stderrlog(void)
 {
@@ -673,7 +692,14 @@ snmp_enable_filelog(const char *logfilename, int dont_zero_log)
 {
     netsnmp_log_handler *logh;
 
-    snmp_disable_filelog();	/* XXX ??? */
+    /*
+     * don't disable ALL filelogs whenever a new one is enabled.
+     * this prevents '-Lf file' from working in snmpd, as the
+     * call to set up /var/log/snmpd.log will disable the previous
+     * log setup. again, this new linked list of log handlers
+     * needs rethinking/cleanup. xxx-rks
+     * snmp_disable_filelog();
+     */
 
     if (logfilename) {
         logh = netsnmp_find_loghandler( logfilename );
@@ -889,7 +915,7 @@ netsnmp_remove_loghandler( netsnmp_log_handler *logh )
 /* ==================================================== */
 
 int
-log_handler_stdouterr(  netsnmp_log_handler* logh, int pri, const char *string)
+log_handler_stdouterr(  netsnmp_log_handler* logh, int pri, const char *str)
 {
     char            sbuf[40];
 
@@ -899,12 +925,12 @@ log_handler_stdouterr(  netsnmp_log_handler* logh, int pri, const char *string)
     } else {
         strcpy(sbuf, "");
     }
-    newline = string[strlen(string) - 1] == '\n';	/* XXX - Eh ? */
+    newline = str[strlen(str) - 1] == '\n';	/* XXX - Eh ? */
 
     if (logh->imagic)
-       printf(         "%s%s", sbuf, string);
+       printf(         "%s%s", sbuf, str);
     else
-       fprintf(stderr, "%s%s", sbuf, string);
+       fprintf(stderr, "%s%s", sbuf, str);
 
     return 1;
 }
@@ -912,7 +938,7 @@ log_handler_stdouterr(  netsnmp_log_handler* logh, int pri, const char *string)
 
 #ifdef WIN32
 int
-log_handler_syslog(  netsnmp_log_handler* logh, int pri, const char *string)
+log_handler_syslog(  netsnmp_log_handler* logh, int pri, const char *str)
 {
     WORD            etype;
     LPCTSTR         event_msg[2];
@@ -953,7 +979,7 @@ log_handler_syslog(  netsnmp_log_handler* logh, int pri, const char *string)
             etype = EVENTLOG_INFORMATION_TYPE;
             break;
     }
-    event_msg[0] = string;
+    event_msg[0] = str;
     event_msg[1] = NULL;
     /* NOTE: 4th parameter must match winservice.mc:MessageId value */
     if (!ReportEvent(eventlog_h, etype, 0, 100, NULL, 1, 0, event_msg, NULL)) {
@@ -969,7 +995,7 @@ log_handler_syslog(  netsnmp_log_handler* logh, int pri, const char *string)
 }
 #else
 int
-log_handler_syslog(  netsnmp_log_handler* logh, int pri, const char *string)
+log_handler_syslog(  netsnmp_log_handler* logh, int pri, const char *str)
 {
 	/*
 	 * XXX
@@ -989,14 +1015,14 @@ log_handler_syslog(  netsnmp_log_handler* logh, int pri, const char *string)
         openlog(ident, LOG_CONS | LOG_PID, facility);
         logh->imagic = 1;
     }
-    syslog( pri, "%s", string );
+    syslog( pri, "%s", str );
     return 1;
 }
 #endif /* !WIN32 */
 
 
 int
-log_handler_file(    netsnmp_log_handler* logh, int pri, const char *string)
+log_handler_file(    netsnmp_log_handler* logh, int pri, const char *str)
 {
     FILE           *fhandle;
     char            sbuf[40];
@@ -1026,14 +1052,14 @@ log_handler_file(    netsnmp_log_handler* logh, int pri, const char *string)
             return 0;
         logh->magic = (void*)fhandle;
     }
-    fprintf(fhandle, "%s%s", sbuf, string);
+    fprintf(fhandle, "%s%s", sbuf, str);
     fflush(fhandle);
-    logh->imagic = string[strlen(string) - 1] == '\n';
+    logh->imagic = str[strlen(str) - 1] == '\n';
     return 1;
 }
 
 int
-log_handler_callback(netsnmp_log_handler* logh, int pri, const char *string)
+log_handler_callback(netsnmp_log_handler* logh, int pri, const char *str)
 {
 	/*
 	 * XXX - perhaps replace 'snmp_call_callbacks' processing
@@ -1043,7 +1069,7 @@ log_handler_callback(netsnmp_log_handler* logh, int pri, const char *string)
     int             dodebug = snmp_get_do_debugging();
 
     slm.priority = pri;
-    slm.msg = string;
+    slm.msg = str;
     if (dodebug)            /* turn off debugging inside the callbacks else will loop */
         snmp_set_do_debugging(0);
     snmp_call_callbacks(SNMP_CALLBACK_LIBRARY, SNMP_CALLBACK_LOGGING, &slm);
@@ -1053,7 +1079,7 @@ log_handler_callback(netsnmp_log_handler* logh, int pri, const char *string)
 }
 
 int
-log_handler_null(    netsnmp_log_handler* logh, int pri, const char *string)
+log_handler_null(    netsnmp_log_handler* logh, int pri, const char *str)
 {
     /*
      * Dummy log handler - just throw away the error completely
@@ -1063,7 +1089,7 @@ log_handler_null(    netsnmp_log_handler* logh, int pri, const char *string)
 }
 
 void
-snmp_log_string(int priority, const char *string)
+snmp_log_string(int priority, const char *str)
 {
     netsnmp_log_handler *logh;
 
@@ -1084,10 +1110,12 @@ snmp_log_string(int priority, const char *string)
     for ( ; logh; logh = logh->next ) {
         /*
          * ... but skipping any handlers with a "maximum priority"
-	 *     that we have already exceeded.
+         *     that we have already exceeded. And don't forget to
+         *     ensure this logging is turned on (see snmp_disable_stderrlog
+         *     and its cohorts).
          */
-        if (priority >= logh->pri_max)
-            logh->handler( logh, priority, string );
+        if (logh->enabled && (priority >= logh->pri_max))
+            logh->handler( logh, priority, str );
     }
 }
 
